@@ -5,7 +5,7 @@ import datetime
 from dpl_geodb.geo_ops import config
 
 @dataclass
-class PictureReference:
+class PictureReference -> int, str:
     original_name: str
     temporary_name: str
     file_size: str
@@ -19,8 +19,8 @@ class PictureReference:
         connection = psycopg2.connect(**db_parameters)
         try:
             cursor = connection.cursor()
-            insert_command = ("INSERT INTO picturereference (original_name, temporary_name, time_recieved) VALUES(%s, %s, %s) RETURNING id;",
-            (self.original_name, self.temporary_name, self.time_recieved, ))
+            insert_command = ("INSERT INTO picturereference (original_name, temporary_name, time_recieved, filesize, lat, lng) VALUES(%s, %s, %s, %s, %s,%s) RETURNING id;",
+            (self.original_name, self.temporary_name, self.time_recieved, self.file_size, self.lat, self.lng, ))
             cursor.execute(insert_command[0], insert_command[1])
             pic_id = cursor.fetchone()[0]
             connection.commit()
